@@ -76,6 +76,8 @@ class V(object):
 
 
 class Query(object):
+    __slots__ = ('db', 'sql', 'params')
+
     """
     Create a new query object that acts on a particular
     SQLite connection instance.
@@ -87,6 +89,14 @@ class Query(object):
         self.sql = sql
         self.params = params
 
+    @property
+    def statement(self):
+        """
+        Joins all of the SQL queries together and then
+        returns the result. It is the query to be ran.
+        """
+        return '\n'.join(self.sql)
+
     def __iter__(self):
         """
         Execute the internally stored SQL query and then
@@ -94,9 +104,8 @@ class Query(object):
         this function as many times as you want but it
         is not deterministic.
         """
-        statement = '\n'.join(self.sql)
         with closing(self.db.cursor()) as cursor:
-            cursor.execute(statement, self.params)
+            cursor.execute(self.statement, self.params)
             for item in cursor:
                 yield item[0]
 
@@ -109,9 +118,11 @@ class Query(object):
         :param statement: The SQL statements to append.
         :param params: The parameters to append.
         """
-        return Query(db=self.db,
-                     sql=self.sql + (statement,),
-                     params=self.params + params)
+        return Query(
+            db=self.db,
+            sql=self.sql + (statement,),
+            params=self.params + params,
+        )
 
     def __call__(self, edge):
         """
@@ -139,17 +150,15 @@ class Query(object):
             destination node is specified then the source
             nodes will be selected.
         """
-        query = '\n'.join(self.sql)
+        query = self.statement
         rel, dst = edge.rel, edge.dst
         statement, params = (
             SQL.compound_fwd_query(query, rel) if dst is None else
             SQL.compound_inv_query(query, rel, dst)
         )
-        return Query(
-            db=self.db,
-            sql=(statement,),
-            params=self.params + params,
-        )
+        return Query(db=self.db,
+                     sql=(statement,),
+                     params=self.params + params)
 
     @property
     def intersection(self):
